@@ -5,67 +5,67 @@ use warnings;
 
 use parent qw(WWW::Giraffi::API::Request);
 
-our $VERSION = '0.13_03';
+our $VERSION = '0.13_04';
 
 sub all {
 
-    my ( $self ) = @_;
-    return $self->search;
+    my ( $self, $other_options ) = @_;
+    return $self->search(undef, $other_options);
 }
 
 sub search {
 
-    my ( $self, $conditions ) = @_;
-    return $self->get( "axions.json", $conditions );
+    my ( $self, $conditions, $other_options ) = @_;
+    return $self->get( "axions.json", $conditions, $other_options );
 }
 
 sub find {
 
-    my ( $self, $id ) = @_;
-    return $self->get( sprintf( "axions/%s.json", $id ) );
+    my ( $self, $id, $other_options ) = @_;
+    return $self->get( sprintf( "axions/%s.json", $id ), undef, $other_options );
 }
 
 sub find_media {
 
-    my ( $self, $id, $conditions ) = @_;
-    return $self->get( sprintf( "axions/%s/media.json", $id ), $conditions );
+    my ( $self, $id, $conditions, $other_options ) = @_;
+    return $self->get( sprintf( "axions/%s/media.json", $id ), $conditions, $other_options );
 }
 
 
 sub create {
 
-    my ( $self, $conditions ) = @_;
-    return $self->post( "axions.json", undef, { axion => $conditions } );
+    my ( $self, $conditions, $other_options ) = @_;
+    return $self->post( "axions.json", undef, { axion => $conditions }, $other_options );
 }
 
 sub exec {
 
-    my ( $self, $id ) = @_;
-    return $self->post( sprintf("axions/%s/execute.json", $id) );
+    my ( $self, $id, $other_options ) = @_;
+    return $self->post( sprintf("axions/%s/execute.json", $id), undef, undef, $other_options );
 }
 
 sub update {
 
-    my ( $self, $id, $conditions ) = @_;
-    return $self->put( sprintf("axions/%s.json", $id), undef, { axion => $conditions } );
+    my ( $self, $id, $conditions, $other_options ) = @_;
+    return $self->put( sprintf("axions/%s.json", $id), undef, { axion => $conditions }, $other_options );
 }
 
 sub destroy {
 
-    my ( $self, $id ) = @_;
-    return $self->delete( sprintf("axions/%s.json", $id) );
+    my ( $self, $id, $other_options ) = @_;
+    return $self->delete( sprintf("axions/%s.json", $id), undef, undef, $other_options );
 }
 
 sub add_media {
 
-    my ( $self, $id, $media_id ) = @_;
-    return $self->put( sprintf("axions/%s/media/%s.json", $id, $media_id), undef, {} );
+    my ( $self, $id, $media_id, $other_options ) = @_;
+    return $self->put( sprintf("axions/%s/media/%s.json", $id, $media_id), undef, {}, $other_options );
 }
 
 sub remove_media {
 
-    my ( $self, $id, $media_id ) = @_;
-    return $self->delete( sprintf("axions/%s/media/%s.json", $id, $media_id) );
+    my ( $self, $id, $media_id, $other_options ) = @_;
+    return $self->delete( sprintf("axions/%s/media/%s.json", $id, $media_id), undef, undef, $other_options );
 }
 
 1;
@@ -78,7 +78,7 @@ WWW::Giraffi::API::Axion - Giraffi API Axion Method Axion Module
 
 =head1 VERSION
 
-0.13_03
+0.13_04
 
 =head1 SYNOPSIS
 
